//CFTTRenderBufferVulkan - [2020-04-13 11:57:46]
#ifndef _CFTTRENDERBUFFERVULKAN_H_
#define _CFTTRENDERBUFFERVULKAN_H_

#include "common.h"
#include <vulkan/vulkan.h>
#include "CFTTTexture.h"
#include "CFTTRenderBuffer.h"

/*

int,int, VkFormat, EFTTTextureType, uint, uchar, uint64_t, EFTTRTTZBufMode

0022563C CFTTRenderBufferVulkan::CFTTRenderBufferVulkan(int,int,VkFormat,EFTTTextureType,uint,uchar,uint64_t,EFTTRTTZBufMode)
00225860 CFTTRenderBufferVulkan::~CFTTRenderBufferVulkan()
002258C0 CFTTRenderBufferVulkan::~CFTTRenderBufferVulkan()
002258CE CFTTRenderBufferVulkan::GetWidth()
002258D2 CFTTRenderBufferVulkan::GetHeight()
002258D6 CFTTRenderBufferVulkan::IsColourBuffer()
002258F0 CFTTRenderBufferVulkan::GetZDepth()
0022590C CFTTRenderBufferVulkan::GetStencilBits()
0022591C CFTTRenderBufferVulkan::GetBPP()
0022594E CFTTRenderBufferVulkan::GetTextureDirect()

vptr_CFTTRenderBufferVulkan_328AEC:
  CFTTRenderBufferVulkan::~CFTTRenderBufferVulkan()
  CFTTRenderBufferVulkan::~CFTTRenderBufferVulkan()
  CFTTRenderBufferVulkan::GetWidth()
  CFTTRenderBufferVulkan::GetHeight()
  CFTTRenderBufferVulkan::IsColourBuffer()
  CFTTRenderBufferVulkan::GetZDepth()
  CFTTRenderBufferVulkan::GetStencilBits()
  CFTTRenderBufferVulkan::GetBPP()
  CFTTRenderBuffer::GetRenderBuffer()
  CFTTRenderBufferVulkan::GetTextureDirect()

vptr_CFTTRenderBufferVulkan


int a2, int a3, VkFormat eVKFormat, EFTTTextureType a5, uint a6, uchar a7, __int64 a8, EFTTRTTZBufMode a9

0x30
*/

class CFTTRenderBufferVulkan : public CFTTRenderBuffer {
public:
  CFTTRenderBufferVulkan(int dwidth, int dheight,
                         VkFormat eVKFormat,
                         EFTTTextureType a5,
                         uint a6, uchar a7,
                         uint64_t a8,
                         EFTTRTTZBufMode eBufMod);  //0022563C
  virtual ~CFTTRenderBufferVulkan();                //00225860 002258C0
  virtual int GetWidth();                           //002258CE
  virtual int GetHeight();                          //002258D2
  virtual bool IsColourBuffer();                    //002258D6
  virtual int GetZDepth();                          //002258F0
  virtual int GetStencilBits();                     //0022590C
  virtual int GetBPP();                             //0022591C
  virtual CFTTTexture* GetTextureDirect();          //0022594E
};

#endif  //_CFTTRENDERBUFFERVULKAN_H_