//CFTTRenderBuffer - [2020-04-13 11:57:46]
#ifndef _CFTTRENDERBUFFER_H_
#define _CFTTRENDERBUFFER_H_

#include "CFTTTexture.h"

/*
0022663A CFTTRenderBuffer::GetRenderBuffer()
*/

enum EFTTRTTZBufMode {
  EFTTRTTZBufMode_0,
  EFTTRTTZBufMode_1,
  EFTTRTTZBufMode_2,
  EFTTRTTZBufMode_3,
  EFTTRTTZBufMode_4,
  EFTTRTTZBufMode_5,
};

class CFTTRenderBuffer {
public:
  CFTTRenderBuffer();
  virtual ~CFTTRenderBuffer();
  virtual int GetWidth() = 0;
  virtual int GetHeight() = 0;
  virtual bool IsColourBuffer() = 0;
  virtual int GetZDepth() = 0;
  virtual int GetStencilBits() = 0;
  virtual int GetBPP() = 0;
  virtual GLint GetRenderBuffer();
  virtual CFTTTexture* GetTextureDirect() = 0;
};

#endif  //_CFTTRENDERBUFFER_H_